@@ -739,7 +739,7 @@ def execute_strategy_multi_asset(
     save_dataframe_to_csv(
         df_trading_journal,
         'trading_journal',
-        string_directory='assets/results',
+        string_directory=display_options['string_results_directory'],
     )
 
     return dict_return
@@ -850,7 +850,7 @@ def execute_strategy_white_noise(
     save_dataframe_to_csv(
         df_trading_journal,
         'trading_journal',
-        string_directory='assets/results',
+        string_directory=display_options['string_results_directory'],
     )
 
     return dict_return
@@ -1009,7 +1009,7 @@ def execute_strategy_ma_crossover(
     save_dataframe_to_csv(
         df_trading_journal,
         'trading_journal',
-        string_directory='assets/results',
+        string_directory=display_options['string_results_directory'],
     )
 
     return dict_return
@@ -1098,7 +1098,7 @@ def test_strategies(
     save_dataframe_to_csv(
         dict_execution_results['df_trading_journal'],
         string_name='trading_journal',
-        string_directory='assets/results',
+        string_directory=display_options['string_results_directory'],
     )
 
     df_performance = evaluate_performance(
