@@ -624,8 +624,9 @@ def evaluate_performance(
         plot_equity_curve(
             df_daily_returns,
             df_daily_benchmark_returns,
+            display_options=display_options,
             boolean_plot=display_options['boolean_plot_equity_curve'],
-            boolean_save_to_disk=display_options['boolean_save_equity_curve_to_disk']
+            boolean_save_to_disk=display_options['boolean_save_equity_curve_to_disk'],
         )
 
     return df_performance
@@ -633,9 +634,10 @@ def evaluate_performance(
 def plot_equity_curve(
         df_daily_returns,
         df_daily_benchmark_returns,
+        display_options,
         boolean_plot=False,
         boolean_relative=False,
-        boolean_save_to_disk=True
+        boolean_save_to_disk=True,
     ):
     """Creates an equity based on daily returns."""
     string_directory = display_options['string_results_directory']
